@@ -1,13 +1,7 @@
-#!/usr/bin/env perl
-
 use strict;
 use warnings;
 
-use feature qw(say);
-
-our $VERSION = "0.01";
-
-require Dummy;    # does not exist anywhere
+use Dummy;    # does not exist anywhere
 
 exit;
 
